#!/bin/sh

JDBC_JAR=
JMX_PORT=3099

BUNDLED_JAVA_HOME=

if [ ! -z "$BUNDLED_JAVA_HOME" ]; then
   JAVA_HOME=$BUNDLED_JAVA_HOME
fi

if [ -z "$JAVA_HOME" ]; then
  echo "Please, set JAVA_HOME before running this script."
  exit 1
fi


CURRENT_DIR=$PWD
PIM_LISTENER_HOME=$CURRENT_DIR

if [ ! -r "$PIM_LISTENER_HOME/bin/pimlistener.sh" ]; then
  cd ..
  PIM_LISTENER_HOME=$PWD
fi

if [ ! -z "$JDBC_JAR" ]; then
  ORIGINAL_JDBC_JAR=$JDBC_JAR
  if  [ ! -r $JDBC_JAR ]; then
      JDBC_JAR=$PIM_LISTENER_HOME/lib/$JDBC_JAR
      if [ ! -r $JDBC_JAR ]; then
         JDBC_JAR=$ORIGINAL_JAR
      fi
  fi
fi

LIBDIR=$PIM_LISTENER_HOME/lib

CLASSPATH=$JDBC_JAR
CLASSPATH=$CLASSPATH:$LIBDIR/commons-collections-3.2.jar
CLASSPATH=$CLASSPATH:$LIBDIR/commons-dbcp-1.2.1.jar
CLASSPATH=$CLASSPATH:$LIBDIR/commons-lang-2.2.jar
CLASSPATH=$CLASSPATH:$LIBDIR/commons-pool-1.3.jar
CLASSPATH=$CLASSPATH:$LIBDIR/log4j-1.2.14.jar
CLASSPATH=$CLASSPATH:$LIBDIR/axis.jar
CLASSPATH=$CLASSPATH:$LIBDIR/jaxrpc.jar
CLASSPATH=$CLASSPATH:$LIBDIR/wsdl4j-1.5.1.jar
CLASSPATH=$CLASSPATH:$LIBDIR/commons-logging-1.1.jar
CLASSPATH=$CLASSPATH:$LIBDIR/commons-discovery-0.4.jar
CLASSPATH=$CLASSPATH:$LIBDIR/saaj.jar

CLASSPATH=$CLASSPATH:$LIBDIR/funambol-push-listener-6.0.3.jar
CLASSPATH=$CLASSPATH:$LIBDIR/funambol-pim-listener-6.0.3.jar
CLASSPATH=$CLASSPATH:$LIBDIR/funambol-framework.jar
CLASSPATH=$CLASSPATH:$LIBDIR/funambol-server.jar
CLASSPATH=$CLASSPATH:$LIBDIR/funambol-ext-6.0.2.jar

JAVA_OPTS="$JAVA_OPTS -Dfunambol.pushlistener.home=$PIM_LISTENER_HOME"


if [ "$1" = "start" ] ; then

  CLASS_NAME=com.funambol.pushlistener.service.PushListener
  JAVA_OPTS="$AVA_OPTS -Dcom.sun.management.jmxremote -Dcom.sun.management.jmxremote.port=$JMX_PORT -Dcom.sun.management.jmxremote.ssl=false -Dcom.sun.management.jmxremote.authenticate=false"

  # Uncomment the following line to enable remote debug
  # JAVA_OPTS=$JAVA_OPTS -Xdebug -Xrunjdwp:transport=dt_socket,address=7777,server=y,suspend=n

  if [ "$2" = "-debug" ] ; then
    "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
    com.funambol.pushlistener.service.PushListener
  else
    "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
    com.funambol.pushlistener.service.PushListener  > /dev/null 2>&1 </dev/zero &
  fi
  
  cd $CURRENT_DIR
  
elif [ "$1" = "stop" ]; then

  echo CLASSPATH: "$CLASSPATH"
  echo JAVA_OPTS: $JAVA_OPTS

  "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
  com.funambol.pushlistener.service.ManagementTools localhost $JMX_PORT stop

  cd $CURRENT_DIR

elif [ "$1" = "console" ] ; then

  echo CLASSPATH: "$CLASSPATH"
  echo JAVA_OPTS: $JAVA_OPTS

  "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
  com.funambol.pimlistener.console.Menu

  cd $CURRENT_DIR
  
elif [ "$1" = "status" ] ; then

  echo CLASSPATH: "$CLASSPATH"
  echo JAVA_OPTS: $JAVA_OPTS

  "$JAVA_HOME/bin/java" $JAVA_OPTS -classpath "$CLASSPATH" \
  com.funambol.pushlistener.service.ManagementTools localhost $JMX_PORT status

  cd $CURRENT_DIR
  
else

  echo "Usage: pimlistener.sh ( commands ... )"
  echo "commands:"
  echo "  start           Start PimListener"
  echo "  start -debug    Start PimListener with output console"
  echo "  stop            Stop  PimListener"
  echo "  console         Start PimListener command line console"
  echo "  status          Show  PimListener status"
  exit 1

fi





